@@ -529,6 +529,7 @@ CHIPSET(0x67C9, 0x67C9, POLARIS10)
 CHIPSET(0x67CA, 0x67CA, POLARIS10)
 CHIPSET(0x67CC, 0x67CC, POLARIS10)
 CHIPSET(0x67CF, 0x67CF, POLARIS10)
+CHIPSET(0x6FDF, 0x6FDF, POLARIS10)
 CHIPSET(0x6980, 0x6980, POLARIS12)
 CHIPSET(0x6981, 0x6981, POLARIS12)
 CHIPSET(0x6985, 0x6985, POLARIS12)
@@ -537,6 +538,9 @@ CHIPSET(0x6987, 0x6987, POLARIS12)
 CHIPSET(0x6995, 0x6995, POLARIS12)
 CHIPSET(0x6997, 0x6997, POLARIS12)
 CHIPSET(0x699F, 0x699F, POLARIS12)
+CHIPSET(0x694C, 0x694C, VEGAM)
+CHIPSET(0x694E, 0x694E, VEGAM)
+CHIPSET(0x694F, 0x694F, VEGAM)
 CHIPSET(0x6860, 0x6860, VEGA10)
 CHIPSET(0x6861, 0x6861, VEGA10)
 CHIPSET(0x6862, 0x6862, VEGA10)
@@ -544,6 +548,25 @@ CHIPSET(0x6863, 0x6863, VEGA10)
 CHIPSET(0x6864, 0x6864, VEGA10)
 CHIPSET(0x6867, 0x6867, VEGA10)
 CHIPSET(0x6868, 0x6868, VEGA10)
+CHIPSET(0x6869, 0x6869, VEGA10)
+CHIPSET(0x686a, 0x686a, VEGA10)
+CHIPSET(0x686b, 0x686b, VEGA10)
 CHIPSET(0x686c, 0x686c, VEGA10)
+CHIPSET(0x686d, 0x686d, VEGA10)
+CHIPSET(0x686e, 0x686e, VEGA10)
+CHIPSET(0x686f, 0x686f, VEGA10)
 CHIPSET(0x687f, 0x687f, VEGA10)
+CHIPSET(0x69A0, 0x69A0, VEGA12)
+CHIPSET(0x69A1, 0x69A1, VEGA12)
+CHIPSET(0x69A2, 0x69A2, VEGA12)
+CHIPSET(0x69A3, 0x69A3, VEGA12)
+CHIPSET(0x69AF, 0x69AF, VEGA12)
+CHIPSET(0x66A0, 0x66A0, VEGA20)
+CHIPSET(0x66A1, 0x66A1, VEGA20)
+CHIPSET(0x66A2, 0x66A2, VEGA20)
+CHIPSET(0x66A3, 0x66A3, VEGA20)
+CHIPSET(0x66A4, 0x66A4, VEGA20)
+CHIPSET(0x66A7, 0x66A7, VEGA20)
+CHIPSET(0x66AF, 0x66AF, VEGA20)
 CHIPSET(0x15dd, 0x15dd, RAVEN)
+CHIPSET(0x15d8, 0x15d8, RAVEN)
